summaryrefslogtreecommitdiffstats
path: root/bibletime/frontend/cprofile.h
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/frontend/cprofile.h')
-rw-r--r--bibletime/frontend/cprofile.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/bibletime/frontend/cprofile.h b/bibletime/frontend/cprofile.h
index 9ef59fd..ffded07 100644
--- a/bibletime/frontend/cprofile.h
+++ b/bibletime/frontend/cprofile.h
@@ -78,9 +78,9 @@ public:
*/
void setGeometry( const TQRect rect );
/**
* Returns the tqgeometry of the main window
*/
- const TQRect tqgeometry();
+ const TQRect geometry();
private:
/**
@@ -94,7 +94,7 @@ private:
TQString m_filename;
bool m_fullscreen;
bool m_maximized;
- TQRect m_tqgeometry;
+ TQRect m_geometry;
};
} //end of namespace Profile
@@ -78,9 +78,9 @@ public:
void setGeometry( const TQRect rect );
/**
- * Returns the tqgeometry of the main window
+ * Returns the geometry of the main window
*/